@@ -1,6 +1,6 @@
 # coding=utf-8
 
-""" Simple example to use python-redfish on HP Proliant servers """
+""" Simple example to use python-redfish on HPE Proliant servers """
 from __future__ import unicode_literals
 from __future__ import print_function
 from __future__ import division
@@ -47,7 +47,7 @@ except redfish.exception.RedfishException as e:
     sys.stderr.write(str(e.advices))
     sys.exit(1)
 
-print ("Redfish API version : %s \n" % remote_mgmt.get_api_version())
+print("Redfish API version : %s \n" % remote_mgmt.get_api_version())
 
 # Uncomment following line to reset the blade !!!
 # remote_mgmt.Systems.systems_dict["1"].reset_system()
