@@ -212,6 +212,32 @@ class Systems(Device):
             # This means we don't have Processors detailed data
             self.simple_storage_collection = None
 
+        hpeflag = False
+        hpflag = False
+        try:
+            self.data.Oem.Hpe
+            try:
+                self.network_adapters_collection = \
+                    hpe.NetworkAdaptersCollection(
+                        self.get_link_url('NetworkAdapters',
+                                          self.data.Oem.Hpe.Links),
+                        connection_parameters)
+            except AttributeError:
+                # This means we don't have NetworkAdapters
+                self.network_adapters_collection = None
+            try:
+                self.smart_storage = \
+                    hpe.SmartStorage(
+                        self.get_link_url('SmartStorage',
+                                          self.data.Oem.Hpe.Links),
+                        connection_parameters)
+            except AttributeError:
+                # This means we don't have SmartStorage
+                self.smart_storage = None
+        except AttributeError:
+            # This means we don't have Hpe oem data
+            hpeflag = True
+
         try:
             self.data.Oem.Hp
             try:
@@ -233,6 +259,10 @@ class Systems(Device):
                 # This means we don't have SmartStorage
                 self.smart_storage = None
         except AttributeError:
+            # This means we don't have Hp oem data
+            hpflag = True
+
+        if hpeflag and hpflag:
             # This means we don't have oem data
             self.data.Oem = None
 
@@ -493,7 +523,7 @@ class EthernetInterfacesCollection(BaseCollection):
                 EthernetInterfaces(link, connection_parameters)
 
 
-class EthernetInterfaces(Base):
+class EthernetInterfaces(Device):
     '''Class to manage redfish EthernetInterfaces.'''
     def get_mac(self):
         '''Get EthernetInterface MacAddress
@@ -572,7 +602,7 @@ class ProcessorsCollection(BaseCollection):
                 Processors(link, connection_parameters)
 
 
-class Processors(Base):
+class Processors(Device):
     '''Class to manage redfish Processors.'''
     def get_speed(self):
         '''Get processor speed
@@ -625,7 +655,7 @@ class SimpleStorageCollection(BaseCollection):
                 SimpleStorage(link, connection_parameters)
 
 
-class SimpleStorage(Base):
+class SimpleStorage(Device):
     '''Class to manage redfish SimpleStorage'''
     def get_status(self):
         '''Get storage status
